@@ -147,7 +147,7 @@ class Certificate(Hook):
         cert = blueprint.template.add_resource(
             CertificateResource("Certificate", **self.properties.data)
         )
-        blueprint.add_output("%sArn" % cert.title, cert.ref())
+        blueprint.add_output(f"{cert.title}Arn", cert.ref())
         blueprint.add_output("ValidateRecordTTL", Ref("ValidateRecordTTL"))
         blueprint.add_output("DomainName", Ref("DomainName"))
         return blueprint
@@ -200,7 +200,7 @@ class Certificate(Hook):
         )["StackResources"]
         if response:
             # can be returned without having a PhysicalResourceId
-            if response[0].get("PhysicalResourceId"):
+            if "PhysicalResourceId" in response[0]:
                 return response[0]["PhysicalResourceId"]
         LOGGER.debug("waiting for certificate to be created...")
         time.sleep(interval)
@@ -227,9 +227,9 @@ class Certificate(Hook):
         """
         if not cert_arn:
             cert_arn = self.get_certificate()
-        cert = self.acm_client.describe_certificate(CertificateArn=cert_arn)[
-            "Certificate"
-        ]
+        cert = self.acm_client.describe_certificate(CertificateArn=cert_arn).get(
+            "Certificate", {}
+        )
 
         try:
             domain_validation = [
@@ -249,16 +249,12 @@ class Certificate(Hook):
 
         if not domain_validation:
             raise ValueError(
-                'No validations with status "{}" found for "{}"'.format(
-                    status, self.args.domain
-                )
+                f'No validations with status "{status}" found for "{self.args.domain}"'
             )
         if len(domain_validation) > 1:
             raise ValueError(
-                'Found {} validation options of status "{}" for "{}"; only one '
-                "option is supported".format(
-                    len(domain_validation), status, self.args.domain
-                )
+                f"Found {len(domain_validation)} validation options of status "
+                f'"{status}" for "{self.args.domain}"; only one option is supported'
             )
         try:
             # the validation option can exists before the record set is ready
@@ -298,14 +294,14 @@ class Certificate(Hook):
         """
         if not records:
             cert_arn = self.get_certificate()
-            cert = self.acm_client.describe_certificate(CertificateArn=cert_arn)[
-                "Certificate"
-            ]
+            cert = self.acm_client.describe_certificate(CertificateArn=cert_arn).get(
+                "Certificate", {}
+            )
 
             records = [
                 opt["ResourceRecord"]
                 for opt in cert.get("DomainValidationOptions", [])
-                if opt["ValidationMethod"] == "DNS"
+                if opt.get("ValidationMethod") == "DNS" and "ResourceRecord" in opt
             ]
         LOGGER.info(
             "removing %i validation record(s) from hosted zone: %s",
@@ -455,7 +451,7 @@ class Certificate(Hook):
                 )
             except ClientError as err:
                 if err.response["Error"]["Message"] != (
-                    "Stack with id {} does not exist".format(self.stack.fqn)
+                    f"Stack with id {self.stack.fqn} does not exist"
                 ):
                     raise
                 LOGGER.warning(
